<template>
    <div class="bbsl-common-page">
        <div class="bbsl-table-search">
            <el-page-header @back="goBack" content="采集任务"> </el-page-header>
            <el-form
                v-model="queryParam"
                :inline="true"
                class="el-form-paddingLeft"
            >
                <el-row :gutter="10">
                    <el-col :span="14">
                        <el-form-item label="任务开始时间">
                            <el-date-picker
                                v-model="querys[1].value"
                                style="width: 400px"
                                value-format="yyyy-MM-dd HH:mm:ss"
                                type="datetimerange"
                                clearable
                                range-separator="至"
                                start-placeholder="开始日期"
                                end-placeholder="结束日期"
                            >
                            </el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="任务状态">
                            <el-select
                                clearable
                                style="width: 100px"
                                v-model="querys[2].value"
                                placeholder="请选择"
                            >
                                <el-option
                                    v-for="item in statusList"
                                    :key="item.value"
                                    :label="item.label"
                                    :value="item.value"
                                >
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item>
                            <el-button
                                type="primary"
                                icon="el-icon-search"
                                @click="handleSearch"
                                >搜索</el-button
                            >
                            <el-button
                                icon="el-icon-refresh"
                                @click="handleReset"
                                >重置</el-button
                            >
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <div
            class="bbsl-table-content bbsl-table-content-paddingTop"
            ref="contentPanel"
        >
            <div class="bbsl-btn-content" ref="btnPanel"></div>
            <el-table
                stripe
                size="mini"
                :max-height="tableMaxHeight"
                ref="multipleSelection"
                v-loading="loading"
                border
                @row-dblclick="handleDbClick"
                :row-key="getRowKey"
                :data="tableData"
                @selection-change="handleSelectionChange"
                :style="{width: '100%'}"
                :header-cell-style="{'text-align': 'center'}"
                :cell-style="{'text-align': 'center'}"
            >
                <el-table-column
                    min-width="170"
                    sortable
                    prop="taskId"
                    label="任务编号"
                    show-overflow-tooltip
                >
                </el-table-column>

                <el-table-column
                    min-width="170"
                    sortable
                    prop="startTime"
                    label="任务开始时间"
                    show-overflow-tooltip
                ></el-table-column>

                <el-table-column
                    min-width="170"
                    sortable
                    prop="endTime"
                    label="任务结束时间"
                    show-overflow-tooltip
                >
                </el-table-column>
                <el-table-column
                    min-width="350"
                    sortable
                    prop="result"
                    label="任务结果"
                    show-overflow-tooltip
                >
                </el-table-column>
                <el-table-column
                    min-width="120"
                    sortable
                    prop="status"
                    label="任务状态"
                    show-overflow-tooltip
                >
                    <template #default="scope">
                        <i
                            :class="
                                scope.row.status == 1 ? 'success_rw' : 'fail_rw'
                            "
                        >
                            {{ scope.row.status === 1 ? '成功' : '失败' }}
                        </i>
                    </template>
                </el-table-column>
            </el-table>
            <el-pagination
                ref="paginationPanel"
                align="right"
                class="bbsl-pagination"
                background
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page"
                :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="total"
            ></el-pagination>
        </div>
        <form-dialog ref="formModal" @reload="reload"></form-dialog>
    </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import logQuery from '@/api/logQuery.js'
import FormDialog from './logQueryDialog.vue'
export default {
    name: 'logQuery',
    components: {
        FormDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            loading: false,
            rangeTime: [],
            startTime: '',
            endTime: '',
            taskId: '', //任务id
            total: 0,
            statusList: [
                {
                    value: 0,
                    label: '失败',
                },
                {
                    value: 1,
                    label: '成功',
                },
            ],
            querys: [
                {
                    group: 'filter',
                    operation: 'EQUAL',
                    property: 'taskId',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'filter',
                    operation: 'BETWEEN',
                    property: 'startTime',
                    relation: 'AND',
                    value: [],
                },
                {
                    group: 'filter',
                    operation: 'EQUAL',
                    property: 'status',
                    relation: 'AND',
                    value: '',
                },
            ],
            sorter: [
                {
                    direction: 'DESC',
                    property: 'startTime',
                },
            ],
        }
    },
    created() {
        this.taskId = this.$route.query.id
    },
    methods: {
        reload() {
            this.loadData(1)
        },
        changeDate(val) {
            if (val) {
                this.startTime = val[0]
                this.endTime = val[1]
            } else {
                this.startTime = ''
                this.endTime = ''
            }
            this.rangeTime = [this.startTime, this.endTime]
            this.querys[1].value = [this.startTime, this.endTime]
        },
        // 指定一个key标识这一行的数据
        getRowKey(row) {
            return row.id
        },
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = ''
            this.querys[2].value = ''
        },
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.sorter = this.sorter
            this.querys[0].value = this.taskId
            this.queryParam.querys = []
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.querys[1].value && this.querys[1].value.length) {
                this.queryParam.querys.push(this.querys[1])
            }
            if (this.querys[2].value !== "" ) {
                this.queryParam.querys.push(this.querys[2])
            }
            logQuery.logList(this.queryParam, (res) => {
                if (res.rows && res.rows.length) {
                    this.total = res.total
                    this.tableData = res.rows
                }
                this.$set(this.tableData)
                this.loading = false
            })
        },
        // 返回上一级
        goBack() {
            this.$router.go(-1)
        },
    },
}
</script>

<style lang="scss" scoped>
	.el-form-paddingLeft {
		width: calc(100% - 180PX);
		padding-left: 40PX;
		box-sizing: border-box;
	}

	.success_rw {
		color: #13ce66;
		font-style: normal;
	}

	.fail_rw {
		color: #ff4949;
		font-style: normal;
	}
</style>
